import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixInnovationWidgetV1Message from './innovation-widget-v1-message-messages.http.js';
export var Sender;
(function (Sender) {
    /** Unknown sender type. */
    Sender["UNKNOWN"] = "UNKNOWN";
    /** AI assistant. */
    Sender["ASSISTANT"] = "ASSISTANT";
    /** Wix user. For example, a site admin. */
    Sender["USER"] = "USER";
    /** Message was sent automatically due to widget settings. For example, a contact form. */
    Sender["SYSTEM"] = "SYSTEM";
    /** Site visitor. */
    Sender["SITE_VISITOR"] = "SITE_VISITOR";
})(Sender || (Sender = {}));
export var MessageType;
(function (MessageType) {
    /** Unknown message type. */
    MessageType["UNKNOWN_MESSAGE_TYPE"] = "UNKNOWN_MESSAGE_TYPE";
    /** Question. */
    MessageType["QUESTION"] = "QUESTION";
    /** Answer. */
    MessageType["ANSWER"] = "ANSWER";
    /** Intro message, as defined in the widget settings. */
    MessageType["INTRO"] = "INTRO";
    /** Legal disclaimer, as defined in the widget settings. */
    MessageType["LEGAL"] = "LEGAL";
    /** Contact form. */
    MessageType["CONTACT_FORM"] = "CONTACT_FORM";
    /** Message confirms that a contact form was successfully submitted. */
    MessageType["CONTACT_FORM_SUBMITTED"] = "CONTACT_FORM_SUBMITTED";
    /** Notification for the site owner. */
    MessageType["SITE_OWNER_NOTIFICATION"] = "SITE_OWNER_NOTIFICATION";
    /** Message informing the site visitor that the AI assistant is offline, as defined in the widget settings. */
    MessageType["OFFLINE"] = "OFFLINE";
    /** Message that informs the Wix user that they have reached the maximum number of messages on their current plan. */
    MessageType["OUT_OF_QUOTA"] = "OUT_OF_QUOTA";
})(MessageType || (MessageType = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Bulk creates messages.
 *
 * This method must be called using the site visitor or site member identity ([SDK](https://dev.wix.com/docs/sdk/articles/get-started/about-identities#site-member) | [REST](https://dev.wix.com/docs/rest/articles/getting-started/about-identities#site-member)) to identify the site visitor that is creating the messages. Therefore, [Wix apps](https://dev.wix.com/docs/build-apps) can't currently call this method using REST.
 * @public
 * @documentationMaturity preview
 * @requiredField options.messages.messageType
 * @requiredField options.messages.sender
 * @permissionId INNOVATION_LAB.CHAT_WIDGET
 * @permissionScope Manage Bookings Services and Settings
 * @permissionScopeId SCOPE.BOOKINGS.CONFIGURATION
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn wix.innovation.assistant.widget.v1.ChatWidget.BulkCreateMessages
 */
export async function bulkCreateMessages(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        messages: options?.messages,
    });
    const reqOpts = ambassadorWixInnovationWidgetV1Message.bulkCreateMessages(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { messages: '$[0].messages' },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves a list of messages.
 *
 * Up to 100 Messages can be returned per request.
 *
 * This method must be called using the site visitor or site member identity ([SDK](https://dev.wix.com/docs/sdk/articles/get-started/about-identities#site-member) | [REST](https://dev.wix.com/docs/rest/articles/getting-started/about-identities#site-member)) to identify the site visitor that is retrieving the messages. Therefore, [Wix apps](https://dev.wix.com/docs/build-apps) can't currently call this method using REST.
 * @public
 * @documentationMaturity preview
 * @param options - Additional options for listing messages.
 * @permissionId INNOVATION_LAB.CHAT_WIDGET
 * @permissionScope Manage Bookings Services and Settings
 * @permissionScopeId SCOPE.BOOKINGS.CONFIGURATION
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @applicableIdentity APP
 * @applicableIdentity VISITOR
 * @fqn wix.innovation.assistant.widget.v1.ChatWidget.ListMessages
 */
export async function listMessages(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        cursorPaging: options?.cursorPaging,
    });
    const reqOpts = ambassadorWixInnovationWidgetV1Message.listMessages(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { cursorPaging: '$[0].cursorPaging' },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=innovation-widget-v1-message-messages.universal.js.map